@@ -7,17 +7,19 @@ test_that("works as expected", {
   # string.
   ecopy( 'hello' )
    
-  # writing to clipboard is not handled in Unix.
-  if( .Platform$OS.type != "unix" ){
+  # reading from the clipboard is not always possible.
+  result = tryCatch({
+      readClipboard(format = 1, raw = FALSE)
+    },
+    error = function(e) {}
+  )
+  if(!is.null(result)){
+
+    expect_equal(result, 'hello')    
 
-    expect_equal(
-      readClipboard( format = 1, raw = FALSE ),
-      'hello'
-    )
-    
     # errors.
     expect_error( { ecopy( iris, showrowcolnames = "wrong", show = 'show' ) }, 'should be one of' )
-
+    
   }
 
 })
\ No newline at end of file
