@@ -46,6 +46,19 @@ test_that("todate works as expected", {
     expect_equal( 
       todate( c( "19940121", "20020222", "20000127", "20010912" ), min.acceptable = NULL, max.acceptable = NULL ),
       lubridate::ymd( c( "19940121", "20020222", "20000127", "20010912" ) )
-    )    
+    )
+
+    # https://github.com/oliver-wyman-actuarial/easyr/issues/24
+    dates = c('26/03/2016', '28/10/2016', '29/12/2016', '23/10/2016', '22/09/2016', '27/12/2016')
+    expect_equal(
+      todate(dates),
+      lubridate::dmy(dates)
+    )
+
+    dates = c('03/26/2016', '10/28/2016', '12/29/2016', '10/23/2016', '09/22/2016', '12/27/2016')
+    expect_equal(
+      todate(dates),
+      lubridate::mdy(dates)
+    )
 
 })
\ No newline at end of file
